scipy.odr.RealData
==================

.. currentmodule:: scipy.odr

.. autoclass:: RealData

   

   .. HACK
      .. autosummary::
         :toctree:
      
         RealData.__init__
         RealData.set_meta



   

